@@ -33,9 +33,10 @@
 #  define KJSAPI_DEPRECATED_NO_EXPORT KJSAPI_NO_EXPORT KJSAPI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KJSAPI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KJSAPI_NO_DEPRECATED
+#    define KJSAPI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
